require 'test_helper'

module AmazonS3IndexProxy
  class ApplicationControllerTest < ActionController::TestCase
    setup do
      Rails.cache.clear
      @routes = Engine.routes
      @url = 'http://example.com'
    end

    test "it renders the file available from :index_file_url" do
      content = "hello world"
      stub_request(:get, @url).to_return(body: content, status: 200)
      get(:index)
      assert_response :ok
      assert_equal @response.body, content
    end

    test "it raises an error if :index_file_url is not set" do
      begin
        AmazonS3IndexProxy.configure { |config| config.index_file_url = nil }
        assert_raises(AmazonS3IndexProxy::ConfigurationMissing) do
          get(:index)
        end
      ensure
        AmazonS3IndexProxy.configure { |config| config.index_file_url = @url }
      end
    end
  end
end
