module AmazonS3IndexProxy
  class ProxyTest < ActiveSupport::TestCase
    def setup
      Timecop.freeze
      Rails.cache.clear
      @url = 'http://example.com'
      @content = "file from the url"
    end

    def teardown
      Timecop.return
      WebMock.reset!
    end

    def make_proxy
      AmazonS3IndexProxy::Proxy.new(@url)
    end

    test "returns the file located at given url address" do
      stub_request(:get, @url).to_return(body: @content, status: 200)
      assert_equal make_proxy.call, @content
    end

    test "caches the file to be used for repeated requests" do
      stub_request(:get, @url).to_return(body: @content, status: 200)
      2.times { make_proxy.call }
      assert_requested(:get, @url, times: 1)
    end

    test "the cache expires in 1 minute by default" do
      stub_request(:get, @url).to_return(body: @content, status: 200)
      make_proxy.call
      Timecop.travel(1.minute.from_now)
      make_proxy.call
      assert_requested(:get, @url, times: 2)
    end
  end
end
